@@ -355,6 +355,11 @@ impl Config {
         Ok(profile)
     }
 
+    /// Returns a reference to the current Profile if there is one.
+    pub fn profile(&self, profile_name: &str) -> Option<&Profile> {
+        self.profile.get(profile_name)
+    }
+
     /// Returns a mutable reference to the current Profile if there is one.
     pub fn profile_mut(&mut self, profile_name: &str) -> Option<&mut Profile> {
         self.profile.get_mut(profile_name)
@@ -390,7 +395,7 @@ impl Config {
 
     /// look up replica config
     /// this will iterate and find all configuration that can resolve config
-    /// 1) match all config that matches criteria including asterik
+    /// 1) match all config that matches criteria including asterisk
     /// 2) apply in terms of precedent
     pub fn resolve_replica_config(&self, _topic_name: &str, _partition: i32) -> Replica {
         /*
