@@ -107,7 +107,7 @@ impl Fluvio {
                 watch_version,
             })
         } else {
-            Err(FluvioError::Other("WatchApi versio not found".to_string()))
+            Err(FluvioError::Other("WatchApi version not found".to_string()))
         }
     }
 
