@@ -1,6 +1,5 @@
 use std::sync::Arc;
 use std::collections::VecDeque;
-use std::time::Duration;
 
 use async_lock::{Mutex, RwLock};
 use dataplane::ReplicaKey;
@@ -12,6 +11,7 @@ use tracing::{debug, info, instrument, error, trace};
 
 use crate::error::{Result, FluvioError};
 use crate::spu::SpuPool;
+use crate::TopicProducerConfig;
 
 use super::ProducerError;
 use super::accumulator::{ProducerBatch, BatchEvents};
@@ -19,64 +19,64 @@ use super::event::EventHandler;
 
 /// Struct that is responsible for sending produce requests to the SPU in a given partition.
 pub(crate) struct PartitionProducer {
+    config: Arc<TopicProducerConfig>,
     replica: ReplicaKey,
     spu_pool: Arc<SpuPool>,
     batches_lock: Arc<Mutex<VecDeque<ProducerBatch>>>,
     batch_events: Arc<BatchEvents>,
-    linger: Duration,
     last_error: Arc<RwLock<Option<ProducerError>>>,
 }
 
 impl PartitionProducer {
     fn new(
+        config: Arc<TopicProducerConfig>,
         replica: ReplicaKey,
         spu_pool: Arc<SpuPool>,
         batches_lock: Arc<Mutex<VecDeque<ProducerBatch>>>,
         batch_events: Arc<BatchEvents>,
-        linger: Duration,
         last_error: Arc<RwLock<Option<ProducerError>>>,
     ) -> Self {
         Self {
+            config,
             replica,
             spu_pool,
             batches_lock,
             batch_events,
-            linger,
             last_error,
         }
     }
 
     pub fn shared(
+        config: Arc<TopicProducerConfig>,
         replica: ReplicaKey,
         spu_pool: Arc<SpuPool>,
         batches: Arc<Mutex<VecDeque<ProducerBatch>>>,
         batch_events: Arc<BatchEvents>,
-        linger: Duration,
         error: Arc<RwLock<Option<ProducerError>>>,
     ) -> Arc<Self> {
         Arc::new(PartitionProducer::new(
+            config,
             replica,
             spu_pool,
             batches,
             batch_events,
-            linger,
             error,
         ))
     }
 
     #[allow(clippy::too_many_arguments)]
     pub(crate) fn start(
+        config: Arc<TopicProducerConfig>,
         replica: ReplicaKey,
         spu_pool: Arc<SpuPool>,
         batches: Arc<Mutex<VecDeque<ProducerBatch>>>,
         batch_events: Arc<BatchEvents>,
-        linger: Duration,
         error: Arc<RwLock<Option<ProducerError>>>,
         end_event: Arc<StickyEvent>,
         flush_event: (Arc<EventHandler>, Arc<EventHandler>),
     ) {
         let producer =
-            PartitionProducer::shared(replica, spu_pool, batches, batch_events, linger, error);
+            PartitionProducer::shared(config, replica, spu_pool, batches, batch_events, error);
         fluvio_future::task::spawn(async move {
             producer.run(end_event, flush_event).await;
         });
@@ -119,7 +119,7 @@ impl PartitionProducer {
 
                 _ = self.batch_events.listen_new_batch() => {
                     debug!("new batch event");
-                    linger_sleep = Some(sleep(self.linger));
+                    linger_sleep = Some(sleep(self.config.linger));
                 }
 
                 _ = async { linger_sleep.as_mut().expect("unexpected failure").await }, if linger_sleep.is_some() => {
@@ -173,7 +173,7 @@ impl PartitionProducer {
         while !batches.is_empty() {
             let ready = force
                 || batches.front().map_or(false, |batch| {
-                    batch.is_full() || batch.create_time().elapsed() >= self.linger
+                    batch.is_full() || batch.elapsed() as u128 >= self.config.linger.as_millis()
                 });
             if ready {
                 if let Some(batch) = batches.pop_front() {
@@ -200,16 +200,18 @@ impl PartitionProducer {
 
         for p_batch in batches_ready {
             let notify = p_batch.notify.clone();
-            let batch = p_batch.try_into()?;
+            let batch = p_batch.batch();
 
-            partition_request.records.batches.push(batch);
+            let raw_batch = batch.try_into()?;
+
+            partition_request.records.batches.push(raw_batch);
 
             batch_notifiers.push(notify);
         }
 
         topic_request.partitions.push(partition_request);
-        request.acks = 1;
-        request.timeout_ms = 1500;
+        request.isolation = self.config.isolation;
+        request.timeout = self.config.timeout;
         request.topics.push(topic_request);
         let response = spu_socket.send_receive(request).await?;
 
